#!/usr/bin/perl
use strict;

use LWP::UserAgent;
use HTTP::Cookies;
use HTML::TreeBuilder;
use JSON;
use Data::Dumper;

my @urls = ("https://www.healthdata.gov/search/field_topic/hospital-17821?query=&sort_by=changed&sort_order=DESC");

my $ua = new LWP::UserAgent;
$ua->agent('Linux Mozilla');
$ua->timeout(120);

my $cookie_jar = HTTP::Cookies->new;
my $tree;
my @inputs;

foreach my $url (@urls) {
	my $response = $ua->get($url);
	if($response->is_success){
		$cookie_jar->extract_cookies($response);
		$ua->cookie_jar($cookie_jar);
		$tree = HTML::TreeBuilder->new_from_content($response->content);
		my @h2 = $tree->look_down( '_tag' => 'h2', class => 'node-title' );
		foreach(@h2) {
			my $a = $_->look_down( '_tag' => 'a');
			if ($a) {
				my $href = $a->attr('href');
				my $response = $ua->get("https://www.healthdata.gov".$href);
				if($response->is_success){
					my $object = {};
					my $tree = HTML::TreeBuilder->new_from_content($response->content);
					my @h2 = $tree->look_down( '_tag' => 'h2', class => 'pane-title' );
					$object->{dataset_name} = $h2[3]->as_text;
					my $d = $tree->look_down( '_tag' => 'div', class => 'field field-name-body field-type-text-with-summary field-label-hidden' );
					if ($d) {
						$object->{dataset_description} = $d->as_text;
					}
					my $table = $tree->look_down( '_tag' => 'table', class => 'field-group-format group_additional' );
					if ($table) {
						my @rows = $table->look_down( '_tag' => 'tr' );
						foreach my $row(@rows) {
							my $field = $row->look_down( '_tag' => 'th', class => 'field-label' );
							if ($field && $field->as_text) {
								$object->{$field->as_text} = $row->look_down( '_tag' => 'td', class => 'field-items' )->as_text;
							}
						}
					}
					my $table2 = $tree->look_down( '_tag' => 'table', class => 'table table-striped table-bordered sticky-enabled' );
					if ($table2) {
						my @rows = $table2->look_down( '_tag' => 'tr' );
							foreach my $row(@rows) {
							my @cells = $row->look_down( '_tag' => 'td' );
							if ($cells[0] && $cells[0]->as_text) {
								$object->{$cells[0]->as_text} = $cells[1]->as_text;
							}
						}
					}
					open(F,">>results.perl.json");
					print F to_json($object, {utf8 => 1}), "\n";
					close(F);
				}
			}
		}
		my $li_next = $tree->look_down( '_tag' => 'li', class => 'pager-next' );
		if ($li_next) {
			push(@urls,"https://www.healthdata.gov".$li_next->look_down( '_tag' => 'a' )->attr('href'));
		} else {
			my $li_first = $tree->look_down( '_tag' => 'li', class => 'pager-first first' );
			if ($li_first) {
				push(@urls,"https://www.healthdata.gov".$li_first->look_down( '_tag' => 'a' )->attr('href'));
			}
		}
		$tree->delete;
	}
}