import scrapy
from scrapper.items import HealthItem

class HealthSpider(scrapy.Spider):
    name = 'health'

    start_urls = ['https://www.healthdata.gov/search/field_topic/hospital-17821?query=&sort_by=changed&sort_order=DESC']

    def parse(self, response):
        # follow links to author pages
        for href in response.css('.search-result-dataset > h2 > a::attr(href)').extract():
            yield scrapy.Request(response.urljoin(href),
                                 callback=self.parse_data, dont_filter=True)

        # follow pagination links
        next_page = response.css('.pagination.pager .pager-next > a::attr(href)').extract_first()
        if next_page is not None:
            next_page = response.urljoin(next_page)
            yield scrapy.Request(next_page, callback=self.parse,dont_filter=True)
        else:
            next_page = response.css('.pagination.pager .pager-first > a::attr(href)').extract_first()
            next_page = response.urljoin(next_page)
            yield scrapy.Request(next_page, callback=self.parse, dont_filter=True)

    def parse_data(self, response):
        item = HealthItem()
        firstTable = response.css('table.field-group-format.group_additional > tbody > tr')
        for row in firstTable:
                item[row.css('th ::text').extract_first()] = row.css("td ::text").extract_first()
        secondTable = response.css('.table-responsive > table > tbody > tr')
        for row in secondTable:
            item[row.css('td:nth-of-type(1) ::text').extract_first()] = row.css('td:nth-of-type(2) ::text').extract_first()
        item['description'] = response.css('div[property="content:encoded"] ::text').extract()
        return item